How To...
=========

This section contains snippets and suggestions about how to perform different actions
using Dask. If you have an idea of a how-to that we should add, please
`make a suggestion <https://github.com/dask/dask/tree/main/docs/source/how-to>`_!

.. Articles in this section should be short and not contain much explanation.

.. toctree::
   :caption: How To...
   :maxdepth: 1
   :glob:

   *
   Use GPUs <../gpu.rst>
